
SapphireQuant
===================
  SapphireQuant is open source package,it can help us generate strategy quickly,and run back test and real trade.

PackageModules:
-------------------
- Channel
- Config
- Core
- DataProcessing
- DataStorage
- Indicator
- Profiles
- Simulate
- Strategy

